Partitioning

Struct Partitioning 

pub struct Partitioning {
    pub kind: PartitioningKind,
    pub length: u8,
    pub value: Vec<u8>,
}
Partitioning is used to specify to which partition the messages should be sent. It has the following kinds:

  • Balanced - the partition ID is calculated by the server using the round-robin algorithm.
  • PartitionId - the partition ID is provided by the client.
  • MessagesKey - the partition ID is calculated by the server using the hash of the provided messages key.

Fields

kind: PartitioningKind

The kind of partitioning.

length: u8

The length of the value payload.

value: Vec<u8>

The binary value payload.

Implementations

Source

impl Partitioning

pub fn balanced() -> Self

Partition the messages using the balanced round-robin algorithm on the server.

pub fn partition_id(partition_id: u32) -> Self

Partition the messages using the provided partition ID.

pub fn messages_key(value: &[u8]) -> Result<Self, IggyError>

Partition the messages using the provided messages key.

pub fn messages_key_str(value: &str) -> Result<Self, IggyError>

Partition the messages using the provided messages key as str.

pub fn messages_key_u32(value: u32) -> Self

Partition the messages using the provided messages key as u32.

pub fn messages_key_u64(value: u64) -> Self

Partition the messages using the provided messages key as u64.

pub fn messages_key_u128(value: u128) -> Self

Partition the messages using the provided messages key as u128.

pub fn from_partitioning(partitioning: &Partitioning) -> Self

Create the partitioning from the provided partitioning.

pub fn from_raw_bytes(bytes: &[u8]) -> Result<Self, IggyError>

Create the partitioning from a raw byte slice.

pub const fn maximum_byte_size() -> usize

Maximum size of the Partitioning struct