pub struct StoreConsumerOffset {
pub consumer: Consumer,
pub stream_id: Identifier,
pub topic_id: Identifier,
pub partition_id: Option<u32>,
pub offset: u64,
}Expand description
StoreConsumerOffset command stores the offset of a consumer for a given partition on the server.
It has additional payload:
consumer- the consumer that is storing the offset, either the regular consumer or the consumer group.stream_id- unique stream ID (numeric or name).topic_id- unique topic ID (numeric or name).partition_id- partition ID on which the offset is stored. Has to be specified for the regular consumer. For consumer group it is ignored (useNone).offset- offset to store.
Fields
consumer: ConsumerThe consumer that is storing the offset, either the regular consumer or the consumer group.
stream_id: IdentifierUnique stream ID (numeric or name).
topic_id: IdentifierUnique topic ID (numeric or name).
partition_id: Option<u32>Partition ID on which the offset is stored. Has to be specified for the regular consumer. For consumer group it is ignored (use None).
offset: u64Offset to store.