pub struct SendMessages {
pub metadata_length: u32,
pub stream_id: Identifier,
pub topic_id: Identifier,
pub partitioning: Partitioning,
pub batch: IggyMessagesBatch,
}Expand description
SendMessages command is used to send messages to a topic in a stream.
It has additional payload:
stream_id- unique stream ID (numeric or name).topic_id- unique topic ID (numeric or name).partitioning- to which partition the messages should be sent - either provided by the client or calculated by the server.batch- collection of messages to be sent.
Fields
metadata_length: u32Length of stream_id, topic_id, partitioning and messages_count (4 bytes)
stream_id: IdentifierUnique stream ID (numeric or name).
topic_id: IdentifierUnique topic ID (numeric or name).
partitioning: PartitioningTo which partition the messages should be sent - either provided by the client or calculated by the server.
batch: IggyMessagesBatchMessages collection
Implementations
Sourceimpl SendMessages
impl SendMessages
pub fn bytes( stream_id: &Identifier, topic_id: &Identifier, partitioning: &Partitioning, messages: &[IggyMessage], ) -> Bytes