pub struct Partitioning {
pub kind: PartitioningKind,
pub length: u8,
pub value: Vec<u8>,
}Expand description
Partitioning is used to specify to which partition the messages should be sent.
It has the following kinds:
Balanced- the partition ID is calculated by the server using the round-robin algorithm.PartitionId- the partition ID is provided by the client.MessagesKey- the partition ID is calculated by the server using the hash of the provided messages key.
Fields
kind: PartitioningKindThe kind of partitioning.
length: u8The length of the value payload.
value: Vec<u8>The binary value payload.
Implementations
Sourceimpl Partitioning
impl Partitioning
Sourcepub fn balanced() -> Self
pub fn balanced() -> Self
Partition the messages using the balanced round-robin algorithm on the server.
Sourcepub fn partition_id(partition_id: u32) -> Self
pub fn partition_id(partition_id: u32) -> Self
Partition the messages using the provided partition ID.
Sourcepub fn messages_key(value: &[u8]) -> Result<Self, IggyError>
pub fn messages_key(value: &[u8]) -> Result<Self, IggyError>
Partition the messages using the provided messages key.
Sourcepub fn messages_key_str(value: &str) -> Result<Self, IggyError>
pub fn messages_key_str(value: &str) -> Result<Self, IggyError>
Partition the messages using the provided messages key as str.
Sourcepub fn messages_key_u32(value: u32) -> Self
pub fn messages_key_u32(value: u32) -> Self
Partition the messages using the provided messages key as u32.
Sourcepub fn messages_key_u64(value: u64) -> Self
pub fn messages_key_u64(value: u64) -> Self
Partition the messages using the provided messages key as u64.
Sourcepub fn messages_key_u128(value: u128) -> Self
pub fn messages_key_u128(value: u128) -> Self
Partition the messages using the provided messages key as u128.
Sourcepub fn from_partitioning(partitioning: &Partitioning) -> Self
pub fn from_partitioning(partitioning: &Partitioning) -> Self
Create the partitioning from the provided partitioning.
Sourcepub fn from_raw_bytes(bytes: &[u8]) -> Result<Self, IggyError>
pub fn from_raw_bytes(bytes: &[u8]) -> Result<Self, IggyError>
Create the partitioning from a raw byte slice.
Sourcepub const fn maximum_byte_size() -> usize
pub const fn maximum_byte_size() -> usize
Maximum size of the Partitioning struct