pub struct Args {Show 43 fields
pub transport: String,
pub encryption_key: String,
pub http_api_url: String,
pub http_retries: u32,
pub username: String,
pub password: String,
pub tcp_server_address: String,
pub tcp_reconnection_enabled: bool,
pub tcp_reconnection_max_retries: Option<u32>,
pub tcp_reconnection_interval: String,
pub tcp_reconnection_reestablish_after: String,
pub tcp_heartbeat_interval: String,
pub tcp_tls_enabled: bool,
pub tcp_tls_domain: String,
pub tcp_tls_ca_file: Option<String>,
pub tcp_nodelay: bool,
pub quic_client_address: String,
pub quic_server_address: String,
pub quic_server_name: String,
pub quic_reconnection_enabled: bool,
pub quic_reconnection_max_retries: Option<u32>,
pub quic_reconnection_interval: String,
pub quic_reconnection_reestablish_after: String,
pub quic_max_concurrent_bidi_streams: u64,
pub quic_datagram_send_buffer_size: u64,
pub quic_initial_mtu: u16,
pub quic_send_window: u64,
pub quic_receive_window: u64,
pub quic_response_buffer_size: u64,
pub quic_keep_alive_interval: u64,
pub quic_max_idle_timeout: u64,
pub quic_validate_certificate: bool,
pub quic_heartbeat_interval: String,
pub websocket_server_address: String,
pub websocket_reconnection_enabled: bool,
pub websocket_reconnection_max_retries: Option<u32>,
pub websocket_reconnection_interval: String,
pub websocket_reconnection_reestablish_after: String,
pub websocket_heartbeat_interval: String,
pub websocket_tls_enabled: bool,
pub websocket_tls_domain: String,
pub websocket_tls_ca_file: Option<String>,
pub websocket_tls_validate_certificate: bool,
}Expand description
The arguments used by the ClientProviderConfig to create a client.
Fields
transport: StringThe transport to use. Valid values are quic, http, tcp and ws
encryption_key: StringOptional encryption key for the message payload used by the client
http_api_url: StringThe optional API URL for the HTTP transport
http_retries: u32The optional number of retries for the HTTP transport
username: Stringpassword: Stringtcp_server_address: StringThe optional client address for the TCP transport
tcp_reconnection_enabled: boolThe optional number of maximum reconnect retries for the TCP transport
tcp_reconnection_max_retries: Option<u32>The optional number of maximum reconnect retries for the TCP transport
tcp_reconnection_interval: StringThe optional reconnect interval for the TCP transport
tcp_reconnection_reestablish_after: StringThe optional re-establish after last connection interval for TCP
tcp_heartbeat_interval: StringThe optional heartbeat interval for the TCP transport
tcp_tls_enabled: boolFlag to enable TLS for the TCP transport
tcp_tls_domain: StringThe optional TLS domain for the TCP transport
tcp_tls_ca_file: Option<String>The optional CA file for the TCP transport
tcp_nodelay: boolDisable nodelay for the TCP transport
quic_client_address: StringThe optional client address for the QUIC transport
quic_server_address: StringThe optional server address for the QUIC transport
quic_server_name: StringThe optional server name for the QUIC transport
quic_reconnection_enabled: boolThe optional number of maximum reconnect retries for the QUIC transport
quic_reconnection_max_retries: Option<u32>The optional number of maximum reconnect retries for the QUIC transport
quic_reconnection_interval: StringThe optional reconnect interval for the QUIC transport
quic_reconnection_reestablish_after: StringThe optional re-establish after last connection interval for QUIC
quic_max_concurrent_bidi_streams: u64The optional maximum number of concurrent bidirectional streams for QUIC
quic_datagram_send_buffer_size: u64The optional datagram send buffer size for QUIC
quic_initial_mtu: u16The optional initial MTU for QUIC
quic_send_window: u64The optional send window for QUIC
quic_receive_window: u64The optional receive window for QUIC
quic_response_buffer_size: u64The optional response buffer size for QUIC
quic_keep_alive_interval: u64The optional keep alive interval for QUIC
quic_max_idle_timeout: u64The optional maximum idle timeout for QUIC
quic_validate_certificate: boolFlag to enable certificate validation for QUIC
quic_heartbeat_interval: StringThe optional heartbeat interval for the QUIC transport
websocket_server_address: StringThe optional server address for the WebSocket transport
websocket_reconnection_enabled: boolThe optional number of maximum reconnect retries for the WebSocket transport
websocket_reconnection_max_retries: Option<u32>The optional number of maximum reconnect retries for the WebSocket transport
websocket_reconnection_interval: StringThe optional reconnect interval for the WebSocket transport
websocket_reconnection_reestablish_after: StringThe optional re-establish after last connection interval for WebSocket
websocket_heartbeat_interval: StringThe optional heartbeat interval for the WebSocket transport
websocket_tls_enabled: boolThe optional TLS enabled for the WebSocket transport
websocket_tls_domain: StringThe optional TLS domain for the WebSocket transport
websocket_tls_ca_file: Option<String>The optional TLS CA file for the WebSocket transport
websocket_tls_validate_certificate: boolThe optional TLS validate certificate for the WebSocket transport
Implementations